@@ -17,6 +17,6 @@ DEFAULT_URANIUM_FILE = "uranium.yaml"
 
 def main(argv=sys.argv[1:]):
     options = docopt(__doc__,  argv=argv)
-    uranium_file = options.get('<uranium_file>', DEFAULT_URANIUM_FILE)
+    uranium_file = options['<uranium_file>'] or DEFAULT_URANIUM_FILE
     uranium = Uranium(uranium_file)
     uranium.run()
