@@ -2,7 +2,8 @@ import yaml
 
 
 def load_config_from_yaml(file_handle):
-    pass
+    config_dict = yaml.load(file_handle.read())
+    return Config(config_dict)
 
 
 class Config(object):
@@ -13,10 +14,6 @@ class Config(object):
     def __init__(self, raw_options):
         self._raw_options = raw_options
 
-    @property
-    def eggs(self):
-        return self['eggs']
-
     def validate(self):
         """
         returns a list of validation errors with the schema
@@ -27,6 +24,14 @@ class Config(object):
                           "eggs must be a list! found {0} instead.".format(type(self.eggs)))
         return errors
 
+    def get(self, key):
+        if key in self._raw_options:
+            return self[key]
+        return None
+
+    def __getitem__(self, key):
+        return self._raw_options.get(key)
+
 
 def _assert_condition(error_list, result, message):
     if not result:
